from ..common.config_schemas import s3_config
import json

def get_tenant_config(tenant_id):
	# todo set the aws values
	# todo document this
	aws_secret_access_key = "test"
	aws_access_key_id = "test"
	aws_session_token = "test"
	config_builder = S3ExportConfiguration.Builder()
	config = config_builder.bucket_name("luke-boyer-audit-test").priv_key(aws_secret_access_key).session_key(aws_session_token).pub_key(aws_access_key_id).build()
	return json.dumps(config.to_dict())


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['immuta_audit_export',
 'immuta_audit_export.common',
 'immuta_audit_export.common.config_schemas',
 'immuta_audit_export.export_record',
 'immuta_audit_export.export_record.s3',
 'immuta_audit_export.tenant_config']

package_data = \
{'': ['*'], 'immuta_audit_export': ['export_all/*']}

install_requires = \
['boto3>=1.21.11,<2.0.0']

setup_kwargs = {
    'name': 'immuta-audit-export',
    'version': '0.1.5',
    'description': 'Scaffold for serverless audit exporting',
    'long_description': None,
    'author': 'LukeBoyer',
    'author_email': 'boyer.l@husky.neu.edu',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
